@@ -1,20 +1,11 @@
 import asyncio
 import concurrent.futures
 
-import nest_asyncio
-
 
 def sig_get(hub) -> asyncio.AbstractEventLoop:
     ...
 
 
-def post_get(hub, ctx):
-    loop = ctx.ret
-    if isinstance(loop, asyncio.BaseEventLoop):
-        nest_asyncio.apply(loop)
-    return loop
-
-
 def sig_policy(hub) -> asyncio.AbstractEventLoopPolicy:
     ...
 
