@@ -2,7 +2,10 @@
 WARNING! This is untested
 """
 import asyncio
-from typing import Any, Callable, Awaitable, Optional
+from typing import Any
+from typing import Awaitable
+from typing import Callable
+from typing import Optional
 
 try:
     import curio
